========
Overview
========

PyMedPhys ships with a graphical user interface (GUI). If you've already
installed `pymedphys` (see
:doc:`Getting Started<../lib/howto/get-started>`), you can start the
GUI by typing the following command in a terminal or command prompt:

.. _`Getting Started`: https://docs.pympedphys.com/lib/howto/get-started.rst

.. code:: bash

    pymedphys gui

You can find the Technical Reference for the App :doc:`here<ref/index>`

Streamlit
*********

The GUI is powered by `Streamlit <https://streamlit.io>`__. Streamlit is
relatively new and is undergoing rapid development. Therefore each PyMedPhys
version, for the time being, will pin to a specific Streamlit version. This
version restriction will be removed once the Streamlit APIs used by PyMedPhys
stabilise.
